"""
Bilibili视频下载工具

一个功能完整的B站视频下载工具,支持:
- 扫码登录/Cookie登录
- 高清视频下载(最高支持8K)
- 自动音视频合并
- 智能目录管理(按日期和BV号+标题分类)
- 封面下载
- 多种清晰度选择
- Whisper语音识别和字幕生成
- Markdown转PDF (支持中文字体和图片嵌入)
"""

__version__ = "1.2.2"
__author__ = "KC"
__email__ = "1549665943@qq.com"
__license__ = "MIT"

from .auth import BilibiliAuth
from .parser import BilibiliParser
from .downloader import BilibiliDownloader
from .transcriber import BilibiliTranscriber
from .pdf_converter import PDFConverter

__all__ = [
    'BilibiliAuth',
    'BilibiliParser', 
    'BilibiliDownloader',
    'BilibiliTranscriber',
    'PDFConverter',
    '__version__',
]
