#!/bin/bash
# B站视频下载工具启动脚本
# 自动设置 WeasyPrint 需要的环境变量

# 设置库路径
export DYLD_LIBRARY_PATH=/opt/homebrew/lib:$DYLD_LIBRARY_PATH

# 激活虚拟环境
source "$(dirname "$0")/venv/bin/activate"

# 运行 bili-dl 命令，传递所有参数
bili-dl "$@"
